![GitHub repo size](https://img.shields.io/github/repo-size/pacotei/flask-vuejs)![GitHub top language](https://img.shields.io/github/languages/top/pacotei/flask-vuejs)![PyPI - Python Version](https://img.shields.io/pypi/pyversions/flask-vuejs)
![PyPI - License](https://img.shields.io/pypi/l/flask-vuejs)

Please read the documentation [here]("https://flaskvue.pacotei.xyz/")